aboutsummaryrefslogtreecommitdiff
path: root/gcc/cppmacro.c
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/cppmacro.c')
-rw-r--r--gcc/cppmacro.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/gcc/cppmacro.c b/gcc/cppmacro.c
index bc12913..1ee91b7 100644
--- a/gcc/cppmacro.c
+++ b/gcc/cppmacro.c
@@ -164,10 +164,10 @@ builtin_macro (pfile, token)
break;
case BT_INCLUDE_LEVEL:
- /* pfile->include_depth counts the primary source as level 1,
- but historically __INCLUDE_DEPTH__ has called the primary
- source level 0. */
- make_number_token (pfile, token, pfile->include_depth - 1);
+ /* The line map depth counts the primary source as level 1, but
+ historically __INCLUDE_DEPTH__ has called the primary source
+ level 0. */
+ make_number_token (pfile, token, pfile->line_maps.depth - 1);
break;
case BT_SPECLINE: